aboutsummaryrefslogtreecommitdiff
path: root/src/jinja/filters.py
diff options
context:
space:
mode:
Diffstat (limited to 'src/jinja/filters.py')
-rw-r--r--src/jinja/filters.py6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/jinja/filters.py b/src/jinja/filters.py
index d090266f..1af7ac88 100644
--- a/src/jinja/filters.py
+++ b/src/jinja/filters.py
@@ -438,10 +438,10 @@ def do_default(value, default_value=u"", boolean=False):
{{ ''|default('the string was empty', true) }}
.. versionchanged:: 2.11
- It's now possible to configure the :class:`~jinja.Environment` with
- :class:`~jinja.ChainableUndefined` to make the `default` filter work
+ It's now possible to configure the :class:`~jinja2.Environment` with
+ :class:`~jinja2.ChainableUndefined` to make the `default` filter work
on nested elements and attributes that may contain undefined values
in the chain without getting an :exc:`~jinja.UndefinedError`.
"""
if isinstance(value, Undefined) or (boolean and not value):
return default_value
@@ -438,10 +438,10 @@ def do_default(value, default_value=u"", boolean=False):
on nested elements and attributes that may contain undefined values
- in the chain without getting an :exc:`~jinja.UndefinedError`.
+ in the chain without getting an :exc:`~jinja2.UndefinedError`.
"""
if isinstance(value, Undefined) or (boolean and not value):